.. certbot-nginx documentation master file, created by
   sphinx-quickstart on Sun Oct 18 13:39:39 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to certbot-nginx's documentation!
=============================================

Contents:

.. toctree::
   :maxdepth: 2


.. toctree::
   :maxdepth: 1

   api


.. automodule:: certbot_nginx
   :members:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

